diff --git a/.ci/dpdk-prepare.sh b/.ci/dpdk-prepare.sh
index f7e6215dd..5543da90a 100755
--- a/.ci/dpdk-prepare.sh
+++ b/.ci/dpdk-prepare.sh
@@ -4,7 +4,7 @@ set -ev
 
 # Installing wheel separately because it may be needed to build some
 # of the packages during dependency backtracking and pip >= 22.0 will
-# abort backtracking on build failures:
+# stop backtracking on build failures:
 #     https://github.com/pypa/pip/issues/10655
 pip3 install --disable-pip-version-check --user wheel
 pip3 install --disable-pip-version-check --user pyelftools
diff --git a/controller/chassis.c b/controller/chassis.c
index 9bb2eba95..4942ba281 100644
--- a/controller/chassis.c
+++ b/controller/chassis.c
@@ -1003,7 +1003,7 @@ store_chassis_index_if_needed(
                 goto out;
             }
         }
-        /* All indices consumed: it's safer to just abort. */
+        /* All indices consumed: it's safer to just exit. */
         VLOG_ERR("All unique controller indices consumed. Exiting.");
         exit(EXIT_FAILURE);
     }
diff --git a/controller/ovn-controller.8.xml b/controller/ovn-controller.8.xml
index 85e7966d7..4953ec93e 100644
--- a/controller/ovn-controller.8.xml
+++ b/controller/ovn-controller.8.xml
@@ -762,7 +762,7 @@
             <code>compute</code>
           </li>
           <li>
-            <code>abort</code>
+            <code>cancel</code>
           </li>
         </ul>
       </dd>
@@ -773,7 +773,7 @@
         Display the <code>ovn-controller</code> engine counter(s) for the
         specified <var>engine_node_name</var>.  <var>counter_name</var> is
         optional and can be one of <code>recompute</code>,
-        <code>compute</code> or <code>abort</code>.
+        <code>compute</code> or <code>cancel</code>.
       </p>
       </dd>
 
diff --git a/controller/ovn-controller.c b/controller/ovn-controller.c
index 453dc62fd..89aa75bc9 100644
--- a/controller/ovn-controller.c
+++ b/controller/ovn-controller.c
@@ -5856,7 +5856,7 @@ main(int argc, char *argv[])
                         /* Even if there's no SB DB transaction available,
                          * try to run the engine so that we can handle any
                          * incremental changes that don't require a recompute.
-                         * If a recompute is required, the engine will abort,
+                         * If a recompute is required, the engine will cancel,
                          * triggerring a full run in the next iteration.
                          */
                         engine_run(false);
@@ -6053,8 +6053,8 @@ main(int argc, char *argv[])
                              " either: br_int %p, chassis %p",
                              br_int, chassis);
                 }
-            } else if (engine_aborted()) {
-                VLOG_DBG("engine was aborted, force recompute next time: "
+            } else if (engine_canceled()) {
+                VLOG_DBG("engine was canceled, force recompute next time: "
                          "br_int %p, chassis %p", br_int, chassis);
                 engine_set_force_recompute(true);
                 poll_immediate_wake();
diff --git a/northd/inc-proc-northd.c b/northd/inc-proc-northd.c
index e1073812c..d56e9783a 100644
--- a/northd/inc-proc-northd.c
+++ b/northd/inc-proc-northd.c
@@ -421,8 +421,8 @@ bool inc_proc_northd_run(struct ovsdb_idl_txn *ovnnb_txn,
         } else {
             VLOG_DBG("engine did not run, and it was not needed");
         }
-    } else if (engine_aborted()) {
-        VLOG_DBG("engine was aborted, force recompute next time.");
+    } else if (engine_canceled()) {
+        VLOG_DBG("engine was canceled, force recompute next time.");
         engine_set_force_recompute(true);
         poll_immediate_wake();
     } else {
diff --git a/tests/ovn-northd.at b/tests/ovn-northd.at
index 680d96675..ec18d2dd4 100644
--- a/tests/ovn-northd.at
+++ b/tests/ovn-northd.at
@@ -59,7 +59,7 @@ $recompute : compute - $compute"
 
   node_stat=$(as northd ovn-appctl -t ovn-northd inc-engine/show-stats $node)
   # node_stat will be of this format :
-  #     - Node: lflow - recompute: 3 - compute: 0 - abort: 0
+  #     - Node: lflow - recompute: 3 - compute: 0 - cancel: 0
   node_recompute_ct=$(echo $node_stat | cut -d '-' -f2 | cut -d ':' -f2)
   node_compute_ct=$(echo $node_stat | cut -d '-' -f3 | cut -d ':' -f2)
 
@@ -9550,14 +9550,14 @@ AT_CHECK([as northd ovn-appctl -t ovn-northd inc-engine/show-stats northd], [0],
 Node: northd
 - recompute:            0
 - compute:              0
-- abort:                0
+- cancel:               0
 ])
 dnl The port_group node recomputes every time a NB port group is added/deleted.
 AT_CHECK([as northd ovn-appctl -t ovn-northd inc-engine/show-stats port_group], [0], [dnl
 Node: port_group
 - recompute:            1
 - compute:              0
-- abort:                0
+- cancel:               0
 ])
 dnl The port_group node is an input for the lflow node.  Port_group
 dnl recompute/compute triggers lflow recompute.
@@ -9565,7 +9565,7 @@ AT_CHECK([as northd ovn-appctl -t ovn-northd inc-engine/show-stats lflow], [0],
 Node: lflow
 - recompute:            1
 - compute:              0
-- abort:                0
+- cancel:               0
 ])
 CHECK_NO_CHANGE_AFTER_RECOMPUTE
 
@@ -9587,7 +9587,7 @@ AT_CHECK([as northd ovn-appctl -t ovn-northd inc-engine/show-stats northd], [0],
 Node: northd
 - recompute:            0
 - compute:              0
-- abort:                0
+- cancel:               0
 ])
 dnl The port_group node recomputes also every time a port from a new switch
 dnl is added to the group.
@@ -9595,7 +9595,7 @@ AT_CHECK([as northd ovn-appctl -t ovn-northd inc-engine/show-stats port_group],
 Node: port_group
 - recompute:            1
 - compute:              0
-- abort:                0
+- cancel:               0
 ])
 dnl The port_group node is an input for the lflow node.  Port_group
 dnl recompute/compute triggers lflow recompute.
@@ -9603,7 +9603,7 @@ AT_CHECK([as northd ovn-appctl -t ovn-northd inc-engine/show-stats lflow], [0],
 Node: lflow
 - recompute:            1
 - compute:              0
-- abort:                0
+- cancel:               0
 ])
 dnl Expect ACL1 on sw1 and sw2
 check_acl_lflows 1 0 1 0
@@ -9623,7 +9623,7 @@ AT_CHECK([as northd ovn-appctl -t ovn-northd inc-engine/show-stats northd], [0],
 Node: northd
 - recompute:            0
 - compute:              0
-- abort:                0
+- cancel:               0
 ])
 dnl The port_group node recomputes also every time a port from a new switch
 dnl is added to the group.
@@ -9631,7 +9631,7 @@ AT_CHECK([as northd ovn-appctl -t ovn-northd inc-engine/show-stats port_group],
 Node: port_group
 - recompute:            1
 - compute:              0
-- abort:                0
+- cancel:               0
 ])
 dnl The port_group node is an input for the lflow node.  Port_group
 dnl recompute/compute triggers lflow recompute (for ACLs).
@@ -9639,7 +9639,7 @@ AT_CHECK([as northd ovn-appctl -t ovn-northd inc-engine/show-stats lflow], [0],
 Node: lflow
 - recompute:            1
 - compute:              0
-- abort:                0
+- cancel:               0
 ])
 dnl Expect both ACLs on sw1 and sw2
 check_acl_lflows 1 1 1 1
@@ -9660,7 +9660,7 @@ AT_CHECK([as northd ovn-appctl -t ovn-northd inc-engine/show-stats northd], [0],
 Node: northd
 - recompute:            0
 - compute:              0
-- abort:                0
+- cancel:               0
 ])
 dnl We did not change the set of switches a pg is applied to, there should be
 dnl no recompute.
@@ -9668,7 +9668,7 @@ AT_CHECK([as northd ovn-appctl -t ovn-northd inc-engine/show-stats port_group],
 Node: port_group
 - recompute:            0
 - compute:              1
-- abort:                0
+- cancel:               0
 ])
 dnl We did not change the set of switches a pg is applied to, there should be
 dnl no recompute.
@@ -9676,7 +9676,7 @@ AT_CHECK([as northd ovn-appctl -t ovn-northd inc-engine/show-stats lflow], [0],
 Node: lflow
 - recompute:            0
 - compute:              1
-- abort:                0
+- cancel:               0
 ])
 dnl Expect both ACLs on sw1 and sw2
 check_acl_lflows 1 1 1 1
@@ -9698,7 +9698,7 @@ AT_CHECK([as northd ovn-appctl -t ovn-northd inc-engine/show-stats northd], [0],
 Node: northd
 - recompute:            0
 - compute:              0
-- abort:                0
+- cancel:               0
 ])
 dnl We did not change the set of switches a pg is applied to, there should be
 dnl no recompute.
@@ -9706,7 +9706,7 @@ AT_CHECK([as northd ovn-appctl -t ovn-northd inc-engine/show-stats port_group],
 Node: port_group
 - recompute:            0
 - compute:              1
-- abort:                0
+- cancel:               0
 ])
 dnl We did not change the set of switches a pg is applied to, there should be
 dnl no recompute.
@@ -9714,7 +9714,7 @@ AT_CHECK([as northd ovn-appctl -t ovn-northd inc-engine/show-stats lflow], [0],
 Node: lflow
 - recompute:            0
 - compute:              1
-- abort:                0
+- cancel:               0
 ])
 dnl Expect both ACLs on sw1 and sw2
 check_acl_lflows 1 1 1 1
@@ -9734,7 +9734,7 @@ AT_CHECK([as northd ovn-appctl -t ovn-northd inc-engine/show-stats northd], [0],
 Node: northd
 - recompute:            0
 - compute:              0
-- abort:                0
+- cancel:               0
 ])
 dnl We changed the set of switches a pg is applied to, there should be
 dnl a recompute.
@@ -9742,7 +9742,7 @@ AT_CHECK([as northd ovn-appctl -t ovn-northd inc-engine/show-stats port_group],
 Node: port_group
 - recompute:            1
 - compute:              0
-- abort:                0
+- cancel:               0
 ])
 dnl We changed the set of switches a pg is applied to, there should be
 dnl a recompute (for ACLs).
@@ -9750,7 +9750,7 @@ AT_CHECK([as northd ovn-appctl -t ovn-northd inc-engine/show-stats lflow], [0],
 Node: lflow
 - recompute:            1
 - compute:              0
-- abort:                0
+- cancel:               0
 ])
 dnl Expect both ACLs on sw1 and only the first one on sw2.
 check_acl_lflows 1 1 1 0
@@ -9771,7 +9771,7 @@ AT_CHECK([as northd ovn-appctl -t ovn-northd inc-engine/show-stats northd], [0],
 Node: northd
 - recompute:            0
 - compute:              0
-- abort:                0
+- cancel:               0
 ])
 dnl We changed the set of switches a pg is applied to, there should be
 dnl a recompute.
@@ -9779,7 +9779,7 @@ AT_CHECK([as northd ovn-appctl -t ovn-northd inc-engine/show-stats port_group],
 Node: port_group
 - recompute:            1
 - compute:              0
-- abort:                0
+- cancel:               0
 ])
 dnl We changed the set of switches a pg is applied to, there should be
 dnl a recompute (for ACLs).
@@ -9787,7 +9787,7 @@ AT_CHECK([as northd ovn-appctl -t ovn-northd inc-engine/show-stats lflow], [0],
 Node: lflow
 - recompute:            1
 - compute:              0
-- abort:                0
+- cancel:               0
 ])
 dnl Expect both ACLs on sw1 and not on sw2.
 check_acl_lflows 1 1 0 0
@@ -9808,7 +9808,7 @@ AT_CHECK([as northd ovn-appctl -t ovn-northd inc-engine/show-stats northd], [0],
 Node: northd
 - recompute:            0
 - compute:              0
-- abort:                0
+- cancel:               0
 ])
 dnl We changed the set of switches a pg is applied to, there should be a
 dnl recompute.
@@ -9816,7 +9816,7 @@ AT_CHECK([as northd ovn-appctl -t ovn-northd inc-engine/show-stats port_group],
 Node: port_group
 - recompute:            1
 - compute:              0
-- abort:                0
+- cancel:               0
 ])
 dnl We changed the set of switches a pg is applied to, there should be a
 dnl recompute.
@@ -9824,7 +9824,7 @@ AT_CHECK([as northd ovn-appctl -t ovn-northd inc-engine/show-stats lflow], [0],
 Node: lflow
 - recompute:            1
 - compute:              0
-- abort:                0
+- cancel:               0
 ])
 dnl Expect both ACLs on sw1 and sw2
 check_acl_lflows 1 1 1 1
@@ -9847,7 +9847,7 @@ AT_CHECK([as northd ovn-appctl -t ovn-northd inc-engine/show-stats northd], [0],
 Node: northd
 - recompute:            0
 - compute:              0
-- abort:                0
+- cancel:               0
 ])
 dnl We changed the set of switches a pg is applied to, there should be a
 dnl recompute.
@@ -9855,7 +9855,7 @@ AT_CHECK([as northd ovn-appctl -t ovn-northd inc-engine/show-stats port_group],
 Node: port_group
 - recompute:            1
 - compute:              0
-- abort:                0
+- cancel:               0
 ])
 dnl We changed the set of switches a pg is applied to, there should be a
 dnl recompute.
@@ -9863,7 +9863,7 @@ AT_CHECK([as northd ovn-appctl -t ovn-northd inc-engine/show-stats lflow], [0],
 Node: lflow
 - recompute:            1
 - compute:              0
-- abort:                0
+- cancel:               0
 ])
 dnl Expect both ACLs on sw1 and no ACLs on sw2
 check_acl_lflows 1 1 0 0
diff --git a/tests/ovs-macros.at b/tests/ovs-macros.at
index 35760cf06..0e3b1bcd6 100644
--- a/tests/ovs-macros.at
+++ b/tests/ovs-macros.at
@@ -280,7 +280,7 @@ dnl Executes shell COMMAND in a loop until it returns
 dnl zero return code.  If COMMAND did not return
 dnl zero code within reasonable time limit, then
 dnl the test fails.  In that case, runs IF-FAILED
-dnl before aborting.
+dnl before exiting.
 m4_define([OVS_WAIT_UNTIL],
   [check_ovs_wait_until_args "$#" "$2"
    OVS_WAIT([$1], [$2], [AT_LINE], [until $1])])
@@ -334,7 +334,7 @@ dnl Executes shell COMMAND in a loop until it returns
 dnl non-zero return code.  If COMMAND did not return
 dnl non-zero code within reasonable time limit, then
 dnl the test fails.  In that case, runs IF-FAILED
-dnl before aborting.
+dnl before exiting.
 m4_define([OVS_WAIT_WHILE],
   [OVS_WAIT([if $1; then return 1; else return 0; fi], [$2],
             [AT_LINE], [while $1])])
diff --git a/utilities/ovn-appctl.8.xml b/utilities/ovn-appctl.8.xml
index 32a42a766..a790e52bb 100644
--- a/utilities/ovn-appctl.8.xml
+++ b/utilities/ovn-appctl.8.xml
@@ -80,7 +80,7 @@
     <dl>
       <dt><code>emer</code></dt>
       <dd>
-        A major failure forced a process to abort.
+        A major failure forced a process to hard stop.
       </dd>
 
       <dt><code>err</code></dt>
@@ -349,4 +349,4 @@
         Prints version information to the console.
       </dd>
     </dl>
-</manpage>
\ No newline at end of file
+</manpage>

diff --git a/lib/inc-proc-eng.c b/lib/inc-proc-eng.c
index 21afcf92b..4b379229e 100644
--- a/lib/inc-proc-eng.c
+++ b/lib/inc-proc-eng.c
@@ -34,7 +34,7 @@
 VLOG_DEFINE_THIS_MODULE(inc_proc_eng);
 
 static bool engine_force_recompute = false;
-static bool engine_run_aborted = false;
+static bool engine_run_canceled = false;
 static const struct engine_context *engine_context;
 
 static struct engine_node **engine_nodes;
@@ -44,7 +44,7 @@ static const char *engine_node_state_name[EN_STATE_MAX] = {
     [EN_STALE]     = "Stale",
     [EN_UPDATED]   = "Updated",
     [EN_UNCHANGED] = "Unchanged",
-    [EN_ABORTED]   = "Aborted",
+    [EN_CANCELED]   = "Canceled",
 };
 
 static long long engine_compute_log_timeout_msec = 500;
@@ -144,16 +144,16 @@ engine_dump_stats(struct unixctl_conn *conn, int argc,
                          "Node: %s\n"
                          "- recompute: %12"PRIu64"\n"
                          "- compute:   %12"PRIu64"\n"
-                         "- abort:     %12"PRIu64"\n",
+                         "- cancel:    %12"PRIu64"\n",
                          node->name, node->stats.recompute,
-                         node->stats.compute, node->stats.abort);
+                         node->stats.compute, node->stats.cancel);
         } else {
             if (!strcmp(dump_stat_type, "recompute")) {
                 ds_put_format(&dump, "%"PRIu64, node->stats.recompute);
             } else if (!strcmp(dump_stat_type, "compute")) {
                 ds_put_format(&dump, "%"PRIu64, node->stats.compute);
-            } else if (!strcmp(dump_stat_type, "abort")) {
-                ds_put_format(&dump, "%"PRIu64, node->stats.abort);
+            } else if (!strcmp(dump_stat_type, "cancel")) {
+                ds_put_format(&dump, "%"PRIu64, node->stats.cancel);
             } else {
                 ds_put_format(&dump, "Invalid stat type : %s", dump_stat_type);
             }
@@ -351,9 +351,9 @@ engine_has_updated(void)
 }
 
 bool
-engine_aborted(void)
+engine_canceled(void)
 {
-    return engine_run_aborted;
+    return engine_run_canceled;
 }
 
 void *
@@ -385,7 +385,7 @@ engine_init_run(void)
 }
 
 /* Do a full recompute (or at least try). If we're not allowed then
  * mark the node as "aborted".
  */
 static void
 engine_recompute(struct engine_node *node, bool allowed,
@@ -399,8 +399,8 @@ engine_recompute(struct engine_node *node, bool allowed,
     va_end(reason_args);
 
     if (!allowed) {
-        VLOG_DBG("node: %s, recompute (%s) aborted", node->name, reason);
-        engine_set_node_state(node, EN_ABORTED);
+        VLOG_DBG("node: %s, recompute (%s) canceled", node->name, reason);
+        engine_set_node_state(node, EN_CANCELED);
         goto done;
     }
 
@@ -454,7 +454,7 @@ engine_compute(struct engine_node *node, bool recompute_allowed)
                 engine_recompute(node, recompute_allowed,
                                  "failed handler for input %s",
                                  node->inputs[i].node->name);
-                return (node->state != EN_ABORTED);
+                return (node->state != EN_CANCELED);
             }
         }
     }
@@ -497,7 +497,7 @@ engine_run_node(struct engine_node *node, bool recompute_allowed)
     }
 
     if (need_compute) {
         /* If we couldn't compute the node we either aborted or triggered
          * a full recompute. In any case, stop processing.
          */
         if (!engine_compute(node, recompute_allowed)) {
@@ -516,20 +516,20 @@ engine_run_node(struct engine_node *node, bool recompute_allowed)
 void
 engine_run(bool recompute_allowed)
 {
     /* If the last run was aborted skip the incremental run because a
      * recompute is needed first.
      */
-    if (!recompute_allowed && engine_run_aborted) {
+    if (!recompute_allowed && engine_run_canceled) {
         return;
     }
 
-    engine_run_aborted = false;
+    engine_run_canceled = false;
     for (size_t i = 0; i < engine_n_nodes; i++) {
         engine_run_node(engine_nodes[i], recompute_allowed);
 
-        if (engine_nodes[i]->state == EN_ABORTED) {
-            engine_nodes[i]->stats.abort++;
-            engine_run_aborted = true;
+        if (engine_nodes[i]->state == EN_CANCELED) {
+            engine_nodes[i]->stats.cancel++;
+            engine_run_canceled = true;
             return;
         }
     }
@@ -385,7 +385,7 @@ engine_init_run(void)
 
 /* Do a full recompute (or at least try). If we're not allowed then
- * mark the node as "aborted".
+ * mark the node as "canceled".
  */
 static void
@@ -497,7 +497,7 @@ engine_run_node(struct engine_node *node, bool recompute_allowed)
 
     if (need_compute) {
-        /* If we couldn't compute the node we either aborted or triggered
+        /* If we couldn't compute the node we either canceled or triggered
          * a full recompute. In any case, stop processing.
          */
@@ -516,20 +516,20 @@ engine_run_node(struct engine_node *node, bool recompute_allowed)
 engine_run(bool recompute_allowed)
 {
-    /* If the last run was aborted skip the incremental run because a
+    /* If the last run was canceled skip the incremental run because a
      * recompute is needed first.
      */
diff --git a/lib/inc-proc-eng.h b/lib/inc-proc-eng.h
index c7e45e739..68bbd8266 100644
--- a/lib/inc-proc-eng.h
+++ b/lib/inc-proc-eng.h
@@ -194,7 +194,7 @@ enum engine_node_state {
     EN_UNCHANGED, /* Data in the node is valid and didn't change during the
                    * last run.
                    */
-    EN_ABORTED,   /* During the last run, processing was aborted for
+    EN_CANCELED,  /* During the last run, processing was canceled for
                    * this node.
                    */
     EN_STATE_MAX,
@@ -203,7 +203,7 @@ enum engine_node_state {
 struct engine_stats {
     uint64_t recompute;
     uint64_t compute;
-    uint64_t abort;
+    uint64_t cancel;
 };
 
 struct engine_node {
@@ -271,7 +271,7 @@ void engine_init_run(void);
 /* Execute the processing, which should be called in the main loop.
  * Updates the engine node's states accordingly. If 'recompute_allowed' is
  * false and a recompute is required by the current engine run then the engine
- * aborts.
+ * cancels its processing.
  */
 void engine_run(bool recompute_allowed);
 
@@ -327,8 +327,8 @@ bool engine_has_run(void);
  * has changed; false if nothing has changed. */
 bool engine_has_updated(void);
 
-/* Returns true if during the last engine run we had to abort processing. */
-bool engine_aborted(void);
+/* Returns true if during the last engine run we had to cancel processing. */
+bool engine_canceled(void);
 
 /* Return a pointer to node data accessible for users outside the processing
  * engine. If the node data is not valid (e.g., last engine_run() failed or